@@ -29,10 +29,17 @@ XPtrTorchTensor tensor_from_r_array (const SEXP x, std::vector<int64_t> dim, std
 
   XPtrTorchTensorOptions options = lantern_TensorOptions();
   
-  if (dtype == "double") {
+  if (dtype == "double") 
+  {
     options = lantern_TensorOptions_dtype(options.get(), XPtrTorchDtype(lantern_Dtype_float64()).get());
-  } else if (dtype == "int") {
+  } 
+  else if (dtype == "int") 
+  {
     options = lantern_TensorOptions_dtype(options.get(), XPtrTorchDtype(lantern_Dtype_int32()).get());
+  } 
+  else if (dtype == "int64")
+  {
+    options = lantern_TensorOptions_dtype(options.get(), XPtrTorchDtype(lantern_Dtype_int64()).get());
   }
 
   options = lantern_TensorOptions_device(options.get(), XPtrTorchDevice(lantern_Device("cpu", 0, false)).get());
@@ -55,17 +62,28 @@ XPtrTorchTensor tensor_from_r_array (const SEXP x, std::vector<int64_t> dim, std
 // [[Rcpp::export]]
 Rcpp::XPtr<XPtrTorchTensor> cpp_torch_tensor (SEXP x, std::vector<std::int64_t> dim,
                                             Rcpp::XPtr<XPtrTorchTensorOptions> options,
-                                            bool requires_grad) {
+                                            bool requires_grad, bool is_integer64) {
 
   XPtrTorchTensor tensor(nullptr);
 
-  if (TYPEOF(x) == INTSXP) {
+  if (TYPEOF(x) == INTSXP) 
+  {
     tensor = tensor_from_r_array<INTSXP>(x, dim, "int");
-  } else if (TYPEOF(x) == REALSXP) {
+  } 
+  else if (TYPEOF(x) == REALSXP && !is_integer64) 
+  {
     tensor = tensor_from_r_array<REALSXP>(x, dim, "double");
-  } else if (TYPEOF(x) == LGLSXP) {
+  } 
+  else if (TYPEOF(x) == REALSXP && is_integer64)
+  {
+    tensor = tensor_from_r_array<REALSXP>(x, dim, "int64");
+  }
+  else if (TYPEOF(x) == LGLSXP) 
+  {
     tensor = tensor_from_r_array<LGLSXP>(x, dim, "int");
-  } else {
+  } 
+  else 
+  {
     Rcpp::stop("R type not handled");
   };
   
@@ -105,6 +123,22 @@ Rcpp::List tensor_to_r_array_int32_t (XPtrTorchTensor x) {
   return Rcpp::List::create(Rcpp::Named("vec") = vec, Rcpp::Named("dim") = tensor_dimensions(x));
 }
 
+Rcpp::List tensor_to_r_array_int64_t (XPtrTorchTensor x)
+{
+  XPtrTorchTensor ten = lantern_Tensor_contiguous(x.get());
+  auto d_ptr = lantern_Tensor_data_ptr_int64_t(ten.get());
+  
+  int64_t len = lantern_Tensor_numel(ten.get());
+  Rcpp::NumericVector vec(len);         // storage vehicle we return them in
+  
+  // transfers values 'keeping bits' but changing type
+  // using reinterpret_cast would get us a warning
+  std::memcpy(&(vec[0]), d_ptr, len * sizeof(double));
+  
+  vec.attr("class") = "integer64"; 
+  return Rcpp::List::create(Rcpp::Named("vec") = vec, Rcpp::Named("dim") = tensor_dimensions(x));
+}
+
 Rcpp::List tensor_to_r_array_bool (XPtrTorchTensor x) {
   XPtrTorchTensor ten = lantern_Tensor_contiguous(x.get());
   auto d_ptr = lantern_Tensor_data_ptr_bool(ten.get());
@@ -142,7 +176,7 @@ Rcpp::List cpp_as_array (Rcpp::XPtr<XPtrTorchTensor> x) {
   }
   
   if (dtype == "Long") {
-    return tensor_to_r_array_int32_t(*x.get());
+    return tensor_to_r_array_int64_t(*x.get());
   }
   
   Rcpp::stop("dtype not handled");
