@@ -166,7 +166,7 @@ test_that("tensordot error message", {
   b <- torch_arange(start = 0, end = 24.)$reshape(c(4, 3, 2))
   
   expect_error(
-    torch_tensordot(a, b, dims_self=c(2, 1), dims_other = c(1, 3)),
+    torch_tensordot(a, b, list(c(2, 1), c(1, 3))),
     regex = "contracted dimensions need to match, but first has size 3 in dim 1 and second has size 2 in dim 3",
     fixed = TRUE
   )
